package com.css.simulation.resource.system.ctrl;

import api.common.pojo.common.ResponseBodyVO;
import api.common.pojo.constants.DictConstants;
import api.common.pojo.param.system.ParameterParam;
import api.common.pojo.param.system.UserParam;
import api.common.pojo.po.system.ParameterPO;
import api.common.pojo.vo.system.ParameterVO;
import api.common.pojo.vo.system.UserVO;
import api.common.util.ObjectUtil;
import com.css.simulation.resource.system.service.ParameterService;
import com.github.pagehelper.PageInfo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;


@Controller()
@RequestMapping("/parameter")
public class ParameterCtrl {

    @Autowired
    ParameterService parameterService;


    /**
     * 查询参数列表
     */
    @RequestMapping("/getParameterList")
    @ResponseBody
    public ResponseBodyVO<PageInfo<ParameterVO>> getParameterList(@RequestBody ParameterParam pageParam){
        ResponseBodyVO<PageInfo<ParameterVO>> response = new ResponseBodyVO<PageInfo<ParameterVO>>(ResponseBodyVO.Response.SUCCESS);
        response.setInfo(parameterService.getParameterList(pageParam));
        return response;
    }

    /**
     * 新增、修改
     */
    @RequestMapping("/saveParameter")
    @ResponseBody
    public ResponseBodyVO<ParameterPO> saveParameter(@RequestBody ParameterPO parameterPO) throws Exception {
        if(ObjectUtil.isNull(parameterPO)){
            return new ResponseBodyVO(false, 400, "参数必传！",null);
        }
        ResponseBodyVO<ParameterPO> response = new ResponseBodyVO<ParameterPO>(ResponseBodyVO.Response.SUCCESS);
        parameterPO = parameterService.saveParameter(parameterPO);
        if(ObjectUtil.isNull(parameterPO.getId())){
            return new ResponseBodyVO(false, 400, "该账户名已存在一条参数配置信息，无法创建！",null);
        }
        response.setInfo(parameterPO);
        return response;
    }


    /**
     * 查看参数配置详情
     */
    @RequestMapping("/getParamInfoById")
    @ResponseBody
    public ResponseBodyVO getParamInfoById(@RequestBody ParameterPO parameterPO) {
        ResponseBodyVO<ParameterVO> response = new ResponseBodyVO<ParameterVO>(ResponseBodyVO.Response.SUCCESS);
        response.setInfo(parameterService.getParamInfoById(parameterPO));
        return response;
    }

    /**
     * 删除算法
     * @return
     */
    @RequestMapping("deleteById")
    @ResponseBody
    public ResponseBodyVO deleteById(@RequestBody ParameterPO parameterPO){
        parameterPO.setIsDeleted(DictConstants.YES);
        int i = parameterService.deleteById(parameterPO);
        if(i>0){
            return new ResponseBodyVO(ResponseBodyVO.Response.SUCCESS);
        }else{
            return new ResponseBodyVO(false, 500, "删除失败！",null);
        }
    }


    /**
     * 模糊查询普通账户
     */
    @RequestMapping("/getUserInfo")
    @ResponseBody
    public ResponseBodyVO<List<UserVO>> getUserInfo(@RequestBody UserParam userParam){
        userParam.setRoleCode(DictConstants.ROLE_CODE_UESR);
        ResponseBodyVO<List<UserVO>> response = new ResponseBodyVO<List<UserVO>>(ResponseBodyVO.Response.SUCCESS);
        response.setInfo(parameterService.getUserInfo(userParam));
        return response;
    }


}
